<template>
    <v-card elevation="3">
        <Head title="Role"/>
        <v-card-title class="subtitle-1">
            Add a role
        </v-card-title>
        <v-divider/>
        <v-card-text class="pa-0">
            <v-form class="mt-3">
                <v-row dense justify="center" align="center">
                    <v-col cols="8">
                        <v-text-field label="Name" v-model="form.name" :loading="loading"
                                      :error-messages="error.name"
                                      outlined dense hide-details/>
                    </v-col>
                    <v-col cols="8">
                        <v-textarea label="Description" v-model="form.description" :loading="loading"
                                      :error-messages="error.description" outlined dense rows="2"/>
                    </v-col>
                </v-row>
            </v-form>
            <v-divider/>
        </v-card-text>
        <v-card-actions>
            <v-row>
                <v-spacer/>
                <v-col align="end">
                    <v-btn class="" text small :loading="loading" @click="storeRole" color="success">
                        Save
                        <v-icon right>mdi-content-save-outline</v-icon>
                    </v-btn>
                </v-col>
            </v-row>
        </v-card-actions>
    </v-card>
</template>

<script>
import Role from "./Role.vue";
import Settings from "../../../Components/Layouts/Settings.vue";
import Setting from "../Setting.vue";

export default {
    name: "RoleCreate",
    layout: [Settings, Setting, Role],
    props: {},
    data() {
        return {
            loading: false,
            error: {
                name: [],
                description: []
            },
            form: {
                name: '',
                description: ''
            },
            eventSubscription: null
        }
    },
    methods: {
        clearError() {
            for (let i in this.error) {
                this.error[i] = []
            }
        },
        storeRole() {
            this.$inertia.post(this.$route('role.store'), this.form, {
                onBefore: () => {
                    this.loading = true
                },
                onSuccess: (page) => {
                    this.showSnack(["Successfully created role!"])
                },
                onError: (errors) => {
                    if (errors && Object.values(errors).length) {
                        this.showSnack([Object.values(errors)[0], "error"])
                    }
                },
                onFinish: visit => {
                    this.loading = false
                },
            });
        }
    },
    mounted() {
    }
}
</script>

<style>

</style>
